YARP 2.1.4 (2007-04-04)                                                {#v2_1_4}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.3...v2.1.4`):

```
   121	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    36	Lorenzo Natale <lorenzo.natale@iit.it>
    12	Claudio Castellini <claudio.castellini@dlr.de>
    11	YARP Developers <yarp0-devel@lists.sourceforge.net>
     5	Giorgio Metta <giorgio.metta@iit.it>
     3	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	Francesco Nori <francesco.nori@iit.it>
```
